// -*- C++ -*-
/*!
 * @file  HandCtrl.cpp
 * @brief open/close controlled RH707 hand
 * @date $Date$
 *
 * $Id$
 */

#include "HandCtrl.h"

// Module specification
// <rtc-template block="module_spec">
static const char* handctrl_spec[] =
  {
    "implementation_id", "HandCtrl",
    "type_name",         "HandCtrl",
    "description",       "open/close controlled RH707 hand",
    "version",           "1.0.0",
    "vendor",            "RTC-Center",
    "category",          "hand",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    "exec_cxt.periodic.rate", "1.0",
    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
HandCtrl::HandCtrl(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_ComRH707Port("ComRH707"),

    // </rtc-template>
	dummy(0)
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  
  // Set OutPort buffer
  
  // Set service provider to Ports
  m_ComRH707Port.registerProvider("com_rh707", "ComRH707", m_com_rh707);
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  registerPort(m_ComRH707Port);
  
  // </rtc-template>

}

/*!
 * @brief destructor
 */
HandCtrl::~HandCtrl()
{
}


RTC::ReturnCode_t HandCtrl::onInitialize()
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t HandCtrl::onFinalize()
{
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t HandCtrl::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t HandCtrl::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

RTC::ReturnCode_t HandCtrl::onActivated(RTC::UniqueId ec_id)
{
  int err; 
  err = m_com_rh707.InitHand();
  if( err != 0 )
    return RTC::RTC_ERROR;
  return RTC::RTC_OK;
}

RTC::ReturnCode_t HandCtrl::onDeactivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}

RTC::ReturnCode_t HandCtrl::onExecute(RTC::UniqueId ec_id)
{
  int err;
  unsigned short cond;
  err = m_com_rh707.GetHandCond(cond);
  if( err != 0 )
    return RTC::RTC_ERROR;
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t HandCtrl::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t HandCtrl::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t HandCtrl::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t HandCtrl::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t HandCtrl::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{
 
  void HandCtrlInit(RTC::Manager* manager)
  {
    RTC::Properties profile(handctrl_spec);
    manager->registerFactory(profile,
                             RTC::Create<HandCtrl>,
                             RTC::Delete<HandCtrl>);
  }
  
};


