// -*- C++ -*-
/*!
 * @file  HandTest.cpp * @brief RH707 hand test component * $Date$ 
 *
 * $Id$ 
 */
#include "HandTest.h"

// Module specification
// <rtc-template block="module_spec">
static const char* handtest_spec[] =
  {
    "implementation_id", "HandTest",
    "type_name",         "HandTest",
    "description",       "RH707 hand test component",
    "version",           "1.0",
    "vendor",            "RTC-Center",
    "category",          "hand",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    // Configuration variables
    ""
  };
// </rtc-template>

HandTest::HandTest(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_ComRH707Port("ComRH707")

    // </rtc-template>
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers

  // Set OutPort buffer

  // Set service provider to Ports

  // Set service consumers to Ports
  m_ComRH707Port.registerConsumer("com_rh707", "ComRH707", m_com_rh707);

  // Set CORBA Service Ports
  registerPort(m_ComRH707Port);

  // </rtc-template>

}

HandTest::~HandTest()
{
}


RTC::ReturnCode_t HandTest::onInitialize()
{
  // <rtc-template block="bind_config">
  // Bind variables and configuration variable

  // </rtc-template>

  return RTC::RTC_OK;
}



RTC::ReturnCode_t HandTest::onFinalize()
{
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t HandTest::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t HandTest::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t HandTest::onActivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t HandTest::onDeactivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

RTC::ReturnCode_t HandTest::onExecute(RTC::UniqueId ec_id)
{
  char  command[1+1];
  short error;

  std::cout << "***** RH707 Hand Open/Close Test *****" << std::endl;
  std::cout << " A:Open                               " << std::endl;
  std::cout << " B:Open(Slowly)                       " << std::endl;
  std::cout << " C:Close                              " << std::endl;
  std::cout << " D:Stop                               " << std::endl;
  std::cout << "**************************************" << std::endl;
  std::cout << " =>";

  std::cin >> command;

  error = m_com_rh707->InitHand();
  if(error != 0) std::cout << "m_com_rh707->InitHand() error" << std::endl;

  if(!strcmp(command,"A")){
    error = m_com_rh707->OpenHand(0);
    if(error != 0) std::cout << "m_com_rh707->OpenHand() error" << std::endl;
  } else if(!strcmp(command,"B")){
    error = m_com_rh707->OpenHand(1);
    if(error != 0) std::cout << "m_com_rh707->OpenHand() error" << std::endl;
  } else if(!strcmp(command,"C")){
    error = m_com_rh707->CloseHand();
    if(error != 0) std::cout << "m_com_rh707->CloseHand() error" << std::endl;
  } else if(!strcmp(command,"D")){
    error = m_com_rh707->StopHand();
    if(error != 0) std::cout << "m_com_rh707->StopHand() error" << std::endl;
  }
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t HandTest::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t HandTest::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t HandTest::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t HandTest::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t HandTest::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


extern "C"
{
 
  void HandTestInit(RTC::Manager* manager)
  {
    RTC::Properties profile(handtest_spec);
    manager->registerFactory(profile,
                             RTC::Create<HandTest>,
                             RTC::Delete<HandTest>);
  }
  
};



